@@ -5,6 +5,7 @@ import sys
 import traceback
 from functools import partial
 from pathlib import Path
+from time import sleep
 
 from batchx import bx
 
@@ -74,7 +75,7 @@ def check_for_acceptable_exit_code(
         return exit_code
 
 
-def get_bx_request(
+def get_bx_submit_request(
     job_service,
     identifier: str,
     tool: str,
@@ -85,8 +86,6 @@ def get_bx_request(
     timeout_s: int = 15 * 60,
     verbose: bool = True,
 ):
-    if environment is None:
-        environment = os.environ["BATCHX_ENV"]
 
     request = job_service.SubmitRequest(
         environment=environment,
@@ -101,16 +100,13 @@ def get_bx_request(
 
 
 def inspect_bx_response(
-    response,
+    error_message: str | None,
+    exit_code: int | None,
     identifier: str,
     acceptable_exit_codes: tuple[int, ...] = (0,),
     inacceptable_exit_code_raise_error: bool = False,
     verbose: bool = True,
 ):
-    # check potential error message
-    error_message = getattr(response, "error_message", None)
-    exit_code = getattr(response, "exit_code", None)
-
     if error_message not in {None, ""}:
         debug_print(
             "{} Error message".format(identifier),
@@ -186,18 +182,21 @@ def run_bx_job(
     memory_mb=DEFAULT_MEMORY_MB,
     timeout_s: int = 15 * 60,
     verbose: bool = True,
-    reraise: bool = True,
+    reraise: bool = False,
     acceptable_exit_codes: tuple[int, ...] = (0,),
     inacceptable_exit_code_raise_error: bool = False,
 ):
     # Initialize
     output_json = dict()
+    if environment is None:
+        environment = os.environ["BATCHX_ENV"]
+
     identifier = "{t} bx job submit".format(t=tool)
 
     bx.connect()
     job_service = bx.JobService()
 
-    request = get_bx_request(
+    submit_request = get_bx_submit_request(
         job_service,
         identifier=identifier,
         tool=tool,
@@ -210,23 +209,28 @@ def run_bx_job(
     )
 
     try:
-        response = job_service.Run(request)
-        debug_print("{} Response".format(identifier), response, verbose=verbose)
+        run_response = job_service.Run(submit_request)
+        debug_print("{} Response".format(identifier), run_response, verbose=verbose)
 
-        output_json = json.loads(getattr(response, "output_json", "{}"))
-        if output_fp is not None:
-            save_json(output_json, output_fp)
-        else:
-            pass
+        # check potential error message
+        error_message = getattr(run_response, "error_message", None)
+        exit_code = getattr(run_response, "exit_code", None)
+        output_json = json.loads(getattr(run_response, "output_json", "{}"))
     except Exception as e:
         handle_unknown_exception(exception=e, identifier=identifier, reraise=reraise)
 
+    if output_fp is not None:
+        save_json(output_json, output_fp)
+    else:
+        pass
+
     exit_code = inspect_bx_response(
-        response=response,
+        error_message=error_message,
+        exit_code=exit_code,
         identifier=identifier,
         acceptable_exit_codes=acceptable_exit_codes,
         inacceptable_exit_code_raise_error=inacceptable_exit_code_raise_error,
         verbose=verbose,
     )
 
-    return exit_code, output_json
+    return exit_code, error_message, output_json
